Support
=======

If you need help you can get in touch via IRC or file an issue on any matter regarding birdears at Github.

===========  ============================================
Media        Channel
===========  ============================================
IRC          #birdears
GitHub       https://github.com/iacchus/birdears
GH issues    https://github.com/iacchus/birdears/issues
ReadTheDocs  https://birdears.readthedocs.io 
PyPI         https://pypi.python.org/pypi/birdears
TravisCI     https://travis-ci.org/iacchus/birdears
Coveralls    https://coveralls.io/github/iacchus/birdears
===========  ============================================


